@@ -80,8 +80,8 @@ Blockly.Python.python_opencv_rectangle=function(a){
     var rect = Blockly.Python.valueToCode(this,'RECT',Blockly.Python.ORDER_ASSIGNMENT);
     var color = this.getFieldValue('COLOR')
     var size = this.getFieldValue('SIZE')
-    var code = 'mxopencv.rectangle('+img+','+rect+',"'+color+'",'+size+')'
-    return [code,Blockly.Python.ORDER_ATOMIC];
+    var code = 'mxopencv.rectangle('+img+','+rect+',"'+color+'",'+size+')\n'
+    return code;
 }
 
 Blockly.Python.python_opencv_readcam = function(a) {
@@ -99,8 +99,8 @@ Blockly.Python.python_opencv_circle=function(a){
     var rad = Blockly.Python.valueToCode(this,'RAD',Blockly.Python.ORDER_ASSIGNMENT);
     var color = this.getFieldValue('COLOR')
     var tk = this.getFieldValue('TK')
-    var code = 'mxopencv.circle('+img+','+xy+','+rad+',"'+color+'",'+tk+')'
-    return [code,Blockly.Python.ORDER_ATOMIC];
+    var code = 'mxopencv.circle('+img+','+xy+','+rad+',"'+color+'",'+tk+')\n'
+    return code;
 }
 
 Blockly.Python.python_opencv_line=function(a){
@@ -111,8 +111,8 @@ Blockly.Python.python_opencv_line=function(a){
     var endxy = Blockly.Python.valueToCode(this,'ENDXY',Blockly.Python.ORDER_ASSIGNMENT);
     var color = this.getFieldValue('COLOR')
     var size = Blockly.Python.valueToCode(this,'SIZE',Blockly.Python.ORDER_ASSIGNMENT);
-    var code = 'mxopencv.line('+img+','+stxy+','+endxy+',"'+color+'",'+size+')'
-    return [code,Blockly.Python.ORDER_ATOMIC];
+    var code = 'mxopencv.line('+img+','+stxy+','+endxy+',"'+color+'",'+size+')\n'
+    return code;
 }
 
 Blockly.Python.opencv_find_camid=function(a){
@@ -120,4 +120,17 @@ Blockly.Python.opencv_find_camid=function(a){
     Blockly.Python.definitions_['Mxopencv'] = 'from Mx import mxopencv';
     var code = 'mxopencv.find_camid()'
     return code;
+}
+
+Blockly.Python.python_opencv_text=function(a){
+    Blockly.Python.definitions_['Opencv'] = 'import cv2';
+    Blockly.Python.definitions_['Mxopencv'] = 'from Mx import mxopencv';
+    var img = Blockly.Python.valueToCode(this,'IMG',Blockly.Python.ORDER_ASSIGNMENT);
+    var text = Blockly.Python.valueToCode(this,'TEXT',Blockly.Python.ORDER_ASSIGNMENT);
+    var xy = Blockly.Python.valueToCode(this,'XY',Blockly.Python.ORDER_ASSIGNMENT);
+    var font_size = Blockly.Python.valueToCode(this,'FONTS',Blockly.Python.ORDER_ASSIGNMENT);
+    var color = this.getFieldValue('COLOR')
+    var size = Blockly.Python.valueToCode(this,'SIZE',Blockly.Python.ORDER_ASSIGNMENT);
+    var code = 'mxopencv.text('+img+','+text+','+xy+','+font_size+',"'+color+'",'+size+')\n'
+    return code;
 }
\ No newline at end of file
