@@ -22,6 +22,9 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
      'print_category': {
        'colour': '#f0932b',
      },
+     'sound_category': {
+      'colour': '#336666',
+    },
      'loop_category': {
        'colour': "#43A047",
      },
@@ -49,6 +52,9 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'display_category': {
         'colour': "#FF9900",
       },
+      'actuator_category':{
+        'colour': "#336699",
+      },
       'sensor_category': {
         'colour': "#bc954e",
       },
@@ -109,6 +115,16 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'colourPrimary': "#bc954e",
       'colourSecondary':"#fff",
       'colourTertiary':"#bc954e"
+    }, 
+    'sound_blocks': {
+      'colourPrimary': "#336666",
+      'colourSecondary':"#fff",
+      'colourTertiary':"#336666"
+    }, 
+    'actuator_blocks': {
+      'colourPrimary': "#336699",
+      'colourSecondary':"#fff",
+      'colourTertiary':"#336699"
     }, 
      'GPIO_blocks': {
       'colourPrimary': "#c19e10",
@@ -774,6 +790,29 @@ nativeDrag          : true,
 dragOpacity         : 1,
 resizable:false,
 resizeOpacity: 1,
+});
+$("#hear_content").PopupWindow({
+  height      : 260,
+  width       : 600,
+  title       : "音频播放",
+  autoOpen    : false,
+  buttons         : {
+    close           : true,          // Boolean
+    maximize        : false,          // Boolean
+    collapse        : false,          // Boolean
+    minimize        : false,          // Boolean
+},
+buttonsTexts        : {
+  close               : "退出",
+  maximize            : "最大化",
+  minimize            : "最小化",
+  collapse            : "搜索",
+}, 
+draggable           : true,
+nativeDrag          : true,
+dragOpacity         : 1,
+resizable:false,
+resizeOpacity: 1,
 });
 
   $("#filemodel").on("click", function(event){
@@ -815,7 +854,14 @@ $("#pip_content").on("uncollapse.popupwindow", function(event){
   var models=document.getElementsByClassName('popupwindow_overlay')
   models[0].style.width='100%'
 })
-
+var wavesurfer = WaveSurfer.create({
+  container: '#waveform',
+  waveColor: 'violet',
+  progressColor: 'purple'
+});
+function hear_wav(url){
+wavesurfer.load(url);
+}
 function pipinstall(){
   clearss()
   list_num_pip=0
@@ -902,12 +948,16 @@ function file_list(){
   var printIcon = function(value, data, cell, row, options){ //plain text value
     var file_type=data.url.substring(data.url.lastIndexOf('.') + 1);
     var jpg_=['png', 'jpg','JPG', 'jpeg', 'bmp', 'gif', 'webp', 'psd', 'svg', 'tiff']
+    var wav_=['wav']
     let result =jpg_.indexOf(file_type)
+    let result_wav =wav_.indexOf(file_type)
     if(result>-1){
       return "<div style='display:flex;justify-content: flex-start;'><div onclick='copy(\""+data.url+"\")'><i class='fa fa-clipboard' style='color: #00bd15;margin-right: 30px;margin-left: 30px;'></i></div><i id='eye' class='fa fa-eye' style='color:#0099CC;margin-right: 30px;' onclick='see_img(\""+data.url+"\")'></i><i class='fa fa-close' style='color: red;' onclick='del(\""+data.url+"\")'></i></div>"
     }
     else{
-      return "<div style='display:flex;justify-content: flex-start;'><i class='fa fa-clipboard' style='color: #00bd15;margin-right: 75px;margin-left: 30px;' onclick='copy(\""+data.url+"\")'></i><i class='fa fa-close' style='color: red;' onclick='del(\""+data.url+"\")'></i></div>"
+      if (result_wav>-1)
+      {return "<div style='display:flex;justify-content: flex-start;'><div onclick='copy(\""+data.url+"\")'><i class='fa fa-clipboard' style='color: #00bd15;margin-right: 30px;margin-left: 30px;'></i></div><i class='hears fa  fa-play-circle' style='color:#0099CC;margin-right: 30px;'onclick='hear_wav(\""+data.url_g+"\")'></i><i class='fa fa-close' style='color: red;' onclick='del(\""+data.url+"\")'></i></div>"}
+      else{return "<div style='display:flex;justify-content: flex-start;'><i class='fa fa-clipboard' style='color: #00bd15;margin-right: 75px;margin-left: 30px;' onclick='copy(\""+data.url+"\")'></i><i class='fa fa-close' style='color: red;' onclick='del(\""+data.url+"\")'></i></div>"}
     }
   };
   $("#file_list").tabulator({
@@ -919,7 +969,7 @@ function file_list(){
   ],
   height:'450px',
   });
-  
+
   $.ajax({
     url:"./file_list",
     type:"GET",
@@ -930,6 +980,11 @@ function file_list(){
           da['last']=dateFormat("YYYY/mm/dd HH:MM:SS", new Date(da['last']))
         }
           $("#file_list").tabulator("setData",data['data'])
+        for (da of data['data']){
+          $(".hears").on("click", function(event){
+            $("#hear_content").PopupWindow("open");
+          });
+        }
       }
     })
 }
@@ -981,7 +1036,18 @@ $(".upfile").on("change","input[type='file']",function(){
      type: 'post',
      data: fd,
      contentType: false,  
-     processData: false,  
+     processData: false,
+     xhr: function() { //用以显示上传进度  
+      var xhr = $.ajaxSettings.xhr();
+      if (xhr.upload) {
+            xhr.upload.addEventListener('progress', function(event) {
+                var percent = Math.floor(event.loaded / event.total * 100); //进度值（百分比制）
+                console.log(percent)
+                document.getElementById('fileupp').innerHTML=percent+'%'
+            }, false);
+          }
+          return xhr
+      },
      success:function (res) {
        if(res=='ok'){
          file_list()
@@ -1191,18 +1257,21 @@ function hsv2rgb_h(h,s,v)
 function pip_list(){
   $("#pip-table").tabulator({columns:[
     {title:"名称", field:"name", sortable:true,align:'center',sorter:"string", width:'20%'},
-    {title:"简介", field:"col", sorter:"string", sortable:false, width:'60%'},
-    {title:"系统", field:"arr", sorter:"string",align:'center',sortable:false, width:'10%'},
+    {title:"简介", field:"col", sorter:"string", sortable:false, width:'50%'},
+    {title:"系统", field:"arr", sorter:"string",align:'center',sortable:false, width:'20%'},
     {title:"操作", field:"cheese", sortable:true,align:'center',width:'10%'},
     ],
     height:'270px',
     }
     )
   $("#pip-table").tabulator("setData",[
-    {id:1, name:"opencv", col:"opencv库", arr:'arrch64',cheese:re('opencv-python')},
-    {id:2, name:"pyqt5",  col:"Pyqt5", arr:'arrch64',cheese:re('pyqt5')},
-    {id:3, name:"Tensorflow 2.8.0",  col:"Tensorflow", arr:'arrch64',cheese:re('tensorflow')},
-    {id:4, name:"Mediapipe",  col:"Mediapipe", arr:'arrch64',cheese:re('mediapipe')},
+    {id:1, name:"opencv", col:"opencv库", arr:'arrch64/windows',cheese:re('opencv-python')},
+    {id:2, name:"pyqt5",  col:"Pyqt5", arr:'arrch64/windows',cheese:re('pyqt5')},
+    {id:3, name:"Tensorflow 2.8.0",  col:"Tensorflow", arr:'arrch64/windows',cheese:re('tensorflow')},
+    {id:4, name:"Mediapipe",  col:"Mediapipe", arr:'arrch64/windwos',cheese:re('mediapipe')},
+    {id:5, name:"sounddevice",  col:"录音与播放音乐", arr:'arrch64/windows',cheese:re('sounddevice')},
+    {id:6, name:"SoundFile",  col:"音频文件操作", arr:'arrch64/windows',cheese:re('SoundFile')},
+    {id:7, name:"librosa",  col:"用于音乐和音频分析的python包", arr:'arrch64/windows',cheese:re('librosa')},
   ]);
 }
 function re(name){
@@ -1214,3 +1283,108 @@ function install_ku(name){
   chatSocket.send(JSON.stringify({'msg':'install_ku','name':name}))
 }
 
+var rec=false
+var recorder
+$("#Recording").on("click", function(event){
+  if (rec==false){
+    recorder = new Recorder({
+      sampleBits: 16,                 // 采样位数，支持 8 或 16，默认是16
+      sampleRate: 16000,              // 采样率，支持 11025、16000、22050、24000、44100、48000，根据浏览器默认值，我的chrome是48000
+      numChannels: 1,                 // 声道，支持 1 或 2， 默认是1
+      // compiling: false,(0.x版本中生效,1.x增加中)  // 是否边录边转换，默认是false
+    });
+    recorder.start().then(() => {
+      add('开始录音')
+      rec=true
+    }, (error) => {
+      // 出错了
+      rec=false
+      if (error.message=='浏览器不支持 getUserMedia !'){
+      prompt(`${error.name} : ${error.message}\n`+
+      '\n'+
+      '原因：浏览器不支持http：IP开头的路径，认为这个路径不安全\n'+
+      '解决方法示例：\n'+
+      '例如chrome浏览器\n'+
+      '1.地址栏输入：chrome://flags/#unsafely-treat-insecure-origin-as-secure\n'+
+      '2.在Insecure origins treated as secure中添加MxPi的IP地址\n'+
+      '3.点击“Relaunch”按钮重启浏览器\n'
+      ,'chrome://flags/#unsafely-treat-insecure-origin-as-secure'
+      )
+      console.log(`${error.name} : ${error.message}`);
+      recorder.destroy().then(function() {
+        recorder = null;
+    });
+  }
+  else{
+    prompt(`${error.name} : ${error.message}\n`,`${error.name} : ${error.message}\n`)
+      recorder.destroy().then(function() {
+        recorder = null;
+    });
+    }
+  });
+  }
+  else{
+    recorder.stop();
+    rec=false;
+    add('录音结束')
+    var data=recorder.getWAVBlob();
+    console.log(data)
+    var fd = new FormData();
+    fd.append('avatar',data);
+    $.ajax({
+        url: '/files',
+        type: 'post',
+        data: fd,
+        contentType: false,  
+        processData: false,  
+        success:function (res) {
+          if(res=='ok'){
+            file_list()
+            document.querySelector("#load-ico").style.visibility="hidden";
+            spop({
+              template: '上传成功',
+              position  : 'top-right',
+              autoclose: 1500,
+              style: 'success'
+            });
+          }
+          else{
+            document.querySelector("#load-ico").style.visibility="hidden";
+            spop({
+              template: '上传错误',
+              position  : 'top-right',
+              autoclose: 1500,
+              style: 'error'
+            });
+          }
+        }
+    })
+  }
+});
+
+function play_wav(){
+  wavesurfer.playPause();
+}
+function pause_wav(){
+  wavesurfer.playPause();
+}
+wavesurfer.on('interaction', function () {
+  t1=wavesurfer.getDuration().toFixed(3)
+  t2=wavesurfer.getCurrentTime().toFixed(3)
+  document.getElementById('wav_time1').innerHTML=t2
+  document.getElementById('wav_time3').innerHTML=t1
+  wavesurfer.pause();
+});
+
+wavesurfer.on('ready', function () {
+  t1=wavesurfer.getDuration().toFixed(3)
+  t2=wavesurfer.getCurrentTime().toFixed(3)
+  document.getElementById('wav_time1').innerHTML=t2
+  document.getElementById('wav_time3').innerHTML=t1
+});
+
+wavesurfer.on('audioprocess', function () {
+  t1=wavesurfer.getDuration().toFixed(3)
+  t2=wavesurfer.getCurrentTime().toFixed(3)
+  document.getElementById('wav_time1').innerHTML=t2
+});
\ No newline at end of file
