@@ -163,7 +163,8 @@ Blockly.Blocks.python_opencv_imread= {
         .appendField(" 粗细")
         .appendField(new Blockly.FieldNumber(2, -1, 10000, 1), "SIZE");
     this.setInputsInline(true);
-    this.setOutput(true, null);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
     this.setStyle('OpenCV_blocks');
     this.setTooltip("在图像上绘制矩形");
     this.setHelpUrl("");
@@ -217,7 +218,8 @@ Blockly.Blocks.python_opencv_imread= {
         .appendField(" 填充")
         .appendField(new Blockly.FieldDropdown([["是","-1"],["否","1"]]), "TK");
     this.setInputsInline(true);
-    this.setOutput(true, null);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
     this.setStyle('OpenCV_blocks');
     this.setTooltip("在图像上绘制圆");
     this.setHelpUrl("");
@@ -241,7 +243,8 @@ Blockly.Blocks.python_opencv_imread= {
         .setCheck(null)
         .appendField("粗细");
     this.setInputsInline(true);
-    this.setOutput(true, null);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
     this.setStyle('OpenCV_blocks');
     this.setTooltip("在图像上绘制直线");
     this.setHelpUrl("");
@@ -258,4 +261,33 @@ Blockly.Blocks.python_opencv_imread= {
     this.setTooltip("检查摄像头id");
     this.setHelpUrl("");
     }
+  };
+
+  Blockly.Blocks.python_opencv_text= {
+    init: function() {
+    this.appendValueInput("IMG")
+        .setCheck(null)
+        .appendField("在图像");
+    this.appendValueInput("TEXT")
+        .setCheck(null)
+        .appendField("上绘制文字");
+    this.appendValueInput("XY")
+        .setCheck(null)
+        .appendField("坐标(x,y)");
+    this.appendValueInput("FONTS")
+        .setCheck(null)
+        .appendField("字体大小");
+    this.appendDummyInput()
+        .appendField("颜色")
+        .appendField(new Blockly.FieldColour("#ff0000"), "COLOR");
+    this.appendValueInput("SIZE")
+        .setCheck(null)
+        .appendField("粗细");
+    this.setInputsInline(true);
+    this.setPreviousStatement(true, null);
+    this.setNextStatement(true, null);
+    this.setStyle('OpenCV_blocks');
+    this.setTooltip("在图像上绘制文字");
+    this.setHelpUrl("");
+    }
   };
\ No newline at end of file
